mafw.db
=======

.. automodule:: mafw.db

   
.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   db_configurations
   db_filter
   db_model
   db_wizard
   fields
   std_tables
   trigger
